#Release Notes

0.2.2
==========
- Fix zookeeper cluster state unicode issue

0.2.0
==========
- Zookeeper states for Solr 6
- handle situations with unknown Solr hostnames
- support stats in the query for Solr 6

0.1.1
==========
- Add support for Python 3.x

0.0.3
==========
- initial version for wukong
